<?php

defined( 'ABSPATH' ) || exit();

class Radio_Player_Proxy_Hooks {
	private static $instance = null;

	public function __construct() {

		// Add proxy URL
		if ( radio_player_get_setting( 'metadataProxy', false ) ) {
			add_filter( 'radio_player/shoutcast_metadata_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/icecast_metadata_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/live365_metadata_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/shoutcast_history_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/icecast_history_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/live365_history_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/itunes_url', [ $this, 'add_proxy_url' ] );
			add_filter( 'radio_player/meta_data_url', [ $this, 'add_proxy_url' ], 10, 2 );
		}

		// HTTP Proxy Enabled
		$is_enabled = radio_player_get_setting( 'httpPlayer', true );

		// IF LOADED OVER HTTP
		$loaded_over_https = ! empty( $_SERVER['HTTPS'] ) && 'off' != $_SERVER['HTTPS'];

		if ( $is_enabled && $loaded_over_https ) {
			add_action( 'template_redirect', [ $this, 'proxy' ] );
		}
	}

	public function add_proxy_url( $url, $type = '' ) {


		$proxy_url = radio_player_get_setting( 'proxyURL', 'https://worldradio.online/proxy/?q=' );

		if ( empty( $proxy_url ) ) {
			$proxy_url = 'https://worldradio.online/proxy/?q='; // Default proxy URL
		}

		if ( $proxy_url == 'https://worldradio.online/proxy/?q=' ) {
			$fs_accounts = get_option( 'fs_accounts' );


			if ( isset( $fs_accounts['sites']['radio-player-proxy'] ) ) {
				$site    = $fs_accounts['sites']['radio-player-proxy'];
				$site_id = isset( $site->id ) ? $site->id : '';

				$url = add_query_arg( [
					'plugin_id' => RADIO_PLAYER_PROXY_FS_PLUGIN_ID,
					'site_id'   => $site_id,
					'q'         => urlencode( $url ),
				], $proxy_url );

				if ( 'title' == $type ) {
					$url = add_query_arg( [
						'type' => 'title',
					], $url );
				}

			}
		} else {
			$url = $proxy_url . urlencode( $url );
		}

		return $url;
	}

	public function proxy() {

		if ( empty( $_GET['radio_player_play'] ) ) {
			return;
		}

		$proxy_url = radio_player_get_setting( 'proxyURL' );

		if ( ! empty( $proxy_url ) ) {
			$uri        = parse_url( @$_SERVER['REQUEST_URI'] );
			$stream_url = str_replace( "radio_player_play=", "", @$uri['query'] );
			$stream_url = urldecode( $stream_url );

			if ( $proxy_url == 'https://worldradio.online/proxy/?q=' ) {
				$fs_accounts = get_option( 'fs_accounts' );
				if ( ! isset( $fs_accounts['sites']['radio-player-proxy'] ) ) {
					return $stream_url;
				}

				$site    = $fs_accounts['sites']['radio-player-proxy'];
				$site_id = $site->id ?? '';

				$stream_url = add_query_arg( [
					'q'         => $stream_url,
					'plugin_id' => RADIO_PLAYER_PROXY_FS_PLUGIN_ID,
					'site_id'   => $site_id,
				], $proxy_url );
			} else {
				$stream_url = $proxy_url . $stream_url;
			}

			wp_redirect( $stream_url );

		} else {
			include_once RADIO_PLAYER_PROXY_PATH . '/proxy/index.php';
		}

		exit();
	}

	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

}

Radio_Player_Proxy_Hooks::instance();