<?php

/**
 * Plugin Name: Radio Player Proxy
 * Plugin URI:  https://softlabbd/radio-player-proxy
 * Description: Play HTTP (Non SSL) radio streams  on HTTPS (SSL installed) website. Also fix the metadata display including currently song title, artist, artwork, and recent play history in the player.
 * Version:     1.0.0
 * Update URI: https://api.freemius.com
 * Author:      SoftLab
 * Author URI:  https://softlabbd.com/
 * Text Domain: radio-player-proxy
 * Domain Path: /languages/
 */
defined( 'ABSPATH' ) || exit;

if ( !function_exists( 'rpp_fs' ) ) {
    // Create a helper function for easy SDK access.
    function rpp_fs()
    {
        global  $rpp_fs ;
        
        if ( !isset( $rpp_fs ) ) {
            // Include Freemius SDK.
            
            if ( file_exists( dirname( dirname( __FILE__ ) ) . '/radio-player/freemius/start.php' ) ) {
                // Try to load SDK from parent plugin folder.
                require_once dirname( dirname( __FILE__ ) ) . '/radio-player/freemius/start.php';
            } else {
                
                if ( file_exists( dirname( dirname( __FILE__ ) ) . '/radio-player-premium/freemius/start.php' ) ) {
                    // Try to load SDK from premium parent plugin folder.
                    require_once dirname( dirname( __FILE__ ) ) . '/radio-player-premium/freemius/start.php';
                } else {
                    require_once dirname( __FILE__ ) . '/freemius/start.php';
                }
            
            }
			class rppFsNull {
				public function can_use_premium_code__premium_only() {
					return true;
				}
				public function add_filter( $tag, $function_to_add, $priority = 10, $accepted_args = 1 ) {
					add_filter( $tag, $function_to_add, $priority, $accepted_args );
				}
				public function add_action( $tag, $function_to_add, $priority = 10, $accepted_args = 1 ) {
					add_action( $tag, $function_to_add, $priority, $accepted_args );
				}
			}
            $rpp_fs = new rppFsNull();
        }
        
        return $rpp_fs;
    }
    
    function rpp_fs_is_parent_active_and_loaded()
    {
        // Check if the parent's init SDK method exists.
        return function_exists( 'rp_fs' );
    }
    
    function rpp_fs_is_parent_active()
    {
        $active_plugins = get_option( 'active_plugins', array() );
        
        if ( is_multisite() ) {
            $network_active_plugins = get_site_option( 'active_sitewide_plugins', array() );
            $active_plugins = array_merge( $active_plugins, array_keys( $network_active_plugins ) );
        }
        
        foreach ( $active_plugins as $basename ) {
            if ( 0 === strpos( $basename, 'radio-player/' ) || 0 === strpos( $basename, 'radio-player-premium/' ) ) {
                return true;
            }
        }
        return false;
    }
    
    function rpp_fs_init()
    {
        if ( defined( 'RADIO_PLAYER_PROXY_PATH' ) ) {
            return;
        }
        define( 'RADIO_PLAYER_PROXY_VERSION', '1.0.0' );
        define( 'RADIO_PLAYER_PROXY_PATH', dirname( __FILE__ ) );
        define( 'RADIO_PLAYER_PROXY_URL', plugin_dir_url( __FILE__ ) );
        define( 'RADIO_PLAYER_PROXY_MIN_RADIO_PLAYER_VERSION', '2.0.72' );
        define( 'RADIO_PLAYER_PROXY_NAME', 'Radio Player Proxy' );
        define( 'RADIO_PLAYER_PROXY_FS_PLUGIN_ID', 13399 );
        
        if ( rpp_fs_is_parent_active_and_loaded() ) {
            // Init Freemius.
            rpp_fs();
            if ( !rpp_fs()->can_use_premium_code__premium_only() ) {
                return;
            }
            // Signal that the add-on's SDK was initiated.
            do_action( 'rpp_fs_loaded' );
            // Parent is active, add your init code here.
            //check min Radio Player version
            
            if ( defined( 'RADIO_PLAYER_VERSION' ) && version_compare( RADIO_PLAYER_VERSION, RADIO_PLAYER_PROXY_MIN_RADIO_PLAYER_VERSION, '<' ) ) {
                add_action( 'admin_notices', function () {
                    $notice = sprintf( '"%1$s" requires "Radio Player" version %2$s or greater. Please update <b>Radio Player</b> to the latest version.', '<strong>' . RADIO_PLAYER_PROXY_NAME . '</strong>', RADIO_PLAYER_PROXY_MIN_RADIO_PLAYER_VERSION );
                    ?>
                    <div class="notice is-dismissible notice-error">
                        <p><?php 
                    echo  $notice ;
                    ?></p>
                    </div>
				<?php 
                } );
                return;
            }
            
            register_activation_hook( __FILE__, function () {
                include_once RADIO_PLAYER_PROXY_PATH . '/includes/class-install.php';
            } );
            include_once RADIO_PLAYER_PROXY_PATH . '/includes/class-hooks.php';
        } else {
            // Parent is inactive, add your error handling here.
            add_action( 'admin_notices', function () {
                $notice = sprintf( '"%1$s" requires "%2$s" to be installed and activated.', '<strong>' . RADIO_PLAYER_PROXY_NAME . '</strong>', '<strong>Radio Player</strong>' );
                ?>
                <div class="notice is-dismissible notice-error">
                    <p><?php 
                echo  $notice ;
                ?></p>
                </div>
			<?php 
            } );
            return;
        }
    
    }

}


if ( rpp_fs_is_parent_active_and_loaded() ) {
    // If parent already included, init add-on.
    rpp_fs_init();
} elseif ( rpp_fs_is_parent_active() ) {
    // Init add-on only after the parent is loaded.
    add_action( 'radio_player_loaded', 'rpp_fs_init' );
} else {
    // Even though the parent is not activated, execute add-on for activation / uninstall hooks.
    rpp_fs_init();
}
